using System;
using System.Drawing;
using System.ComponentModel;
using System.Windows.Forms;
using DicomObjects;
using DicomObjects.EventArguments;
using System.IO;

namespace Sample_Viewer_Program
{
    /// <summary>
    /// Summary description for Form1.
    /// </summary>
    public class Form1 : Form
    {
        private MainMenu mainMenu1;
        private MenuItem menuItem1;
        private MenuItem menuItem8;
        private MenuItem menuItem9;
        private MenuItem menuItem12;
        private MenuItem menuItem17;
        private MenuItem menuItem23;
        private MenuItem menuItem26;
        private MenuItem menuItem28;
        private Label Displayvalues;
        private TextBox PatientName;
        private GroupBox groupBox1;
        private TrackBar LevelSlider;
        private TrackBar WidthSlider;
        private TextBox Level1;
        private TextBox Width1;
        private TextBox Zoom1;
        private GroupBox groupBox2;
        private RadioButton SelectBTN;
        private RadioButton WindowBTN;
        private RadioButton ScrollBTN;
        private RadioButton AddAnnoBTN;
        private RadioButton EditAnnoBTN;
        private RadioButton MagnifyBTN;
        private RadioButton CropBTN;
        private RadioButton CobbBTN;
        private RadioButton ProtractorBTN;
        private RadioButton MeasureBTN;
        private RadioButton PixelBTN;
        private Label label4;
        private Label label5;
        private Label label6;
        private NumericUpDown CImageIndex;
        private NumericUpDown Rows;
        private NumericUpDown Columns;
        private CheckBox AnatomicMarkers;
        private GroupBox groupBox3;
        private Label label7;
        private Label label8;
        private RadioButton PixelValue;
        private RadioButton MovingAverage;
        private RadioButton Replicate;
        private RadioButton BSpine;
        private RadioButton CubicSpine;

        private OpenFileDialog openFileDialog1;
        private SaveFileDialog saveFileDialog1;

        // ============================ My Variables ============================
        private DicomServer server;

        public enum MouseFunctionEnums
        {
            None = 0,
            SelectImage = 1,
            Windowing = 2,
            Scroll = 3,
            AddAnnotation = 4,
            Measure = 5,
            EditAnnotation = 6,
            MagnifyingGlass = 7,
            PixelValues = 8,
            CropImage = 9,
            CobbMeasurement = 10,
            Protractor = 11
        }

        public enum LabelEdgeType
        {
            TopLeft,
            TopRight,
            BottomRight,
            BottomLeft
        }
        private LabelEdgeType LabelEdge;

        private MouseFunctionEnums MouseFunction;
        private bool isSelectedImage;
        private DicomImage SelectedImage;
        private System.Drawing.Printing.PrintDocument printDoc;
        private DicomImage WindowedImage, ScrolledImage;
        private float BaseX, BaseY;
        private bool LabelSelected;
        private DicomLabel CurrentLabel;
        private DicomLabel InfoLabel;
        private bool LabelDrawing;
        private bool Zooming;
        private int ZoomIndex;
        private DicomImage ZoomImage;
        private int ClickNum;
        private int[] XYCoord = new int[6];
        private double[] CobbCoord = new double[8];
        private PointF[] LabelPoints;
        private int InitialX, InitialY;
        private float InitialTop, InitialHeight, InitialWidth, InitialLeft;

        OptionsBoxType OptionsBox;
        RetrieveDialogType RetrieveBox;
        ImageInformationType AttributeForm;
        AboutBoxType AboutBox;
        LabelFormType LabelForm;
        // ============================ My Variables ============================

        private MenuItem Menu_ReadFiles;
        private MenuItem Menu_WriteFiles;
        private MenuItem Menu_PrintDICOM;
        private MenuItem Menu_PrintWindows;
        private MenuItem Menu_Import;
        private MenuItem Menu_Export;
        private TrackBar ZoomSlider;
        private MenuItem Menu_DeleteSelected;
        private MenuItem Menu_DeleteAll;
        private MenuItem Menu_Verify;
        private MenuItem Menu_Retrieve;
        private MenuItem Menu_SendSelected;
        private MenuItem Menu_SendAll;
        private MenuItem Menu_DisplayNormal;
        private MenuItem Menu_FlipHorizontal;
        private MenuItem Menu_FlipVertical;
        private MenuItem Menu_RotateClockwise;
        private MenuItem Menu_RotateAntiClockwise;
        private MenuItem Menu_ViewImageInformation;
        private MenuItem Menu_ViewOption;
        private MenuItem Menu_ShowLoggingOptions;
        private MenuItem Menu_MakeNewImage;
        private MenuItem Menu_AboutThisExample;
        private Label ZoomLabel;
        private CheckBox StretchToFit;
        private Label WidthLabel;
        private Label LevelLabel;
        private MenuItem menuItem2;
        private MenuItem Menu_CineModeForward;
        private MenuItem Menu_CineModeRepeat;
        private MenuItem Menu_CineModeOscillate;
        private MenuItem Menu_CineModeRepeatReverse;
        private MenuItem Menu_CineModeReverse;
        private MenuItem Menu_CineModeStatic;
        private DicomViewer Viewer;
        private IContainer components;
        private DicomObjects.Enums.FilterMode miniMode;
        private DicomObjects.Enums.FilterMode magiMode;

        public Form1()
        {
            //
            // Required for Windows Form Designer support
            //
            InitializeComponent();

            OptionsBox = new OptionsBoxType();
            AttributeForm = new ImageInformationType();
            RetrieveBox = new RetrieveDialogType();
            LabelForm = new LabelFormType();
            //
        }

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (components != null)
                {
                    components.Dispose();
                }
            }
            base.Dispose(disposing);
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.components = new System.ComponentModel.Container();
            this.mainMenu1 = new MainMenu(this.components);
            this.menuItem1 = new MenuItem();
            this.Menu_ReadFiles = new MenuItem();
            this.Menu_WriteFiles = new MenuItem();
            this.Menu_PrintDICOM = new MenuItem();
            this.Menu_PrintWindows = new MenuItem();
            this.Menu_Import = new MenuItem();
            this.Menu_Export = new MenuItem();
            this.menuItem8 = new MenuItem();
            this.menuItem9 = new MenuItem();
            this.Menu_DeleteSelected = new MenuItem();
            this.Menu_DeleteAll = new MenuItem();
            this.menuItem12 = new MenuItem();
            this.Menu_Verify = new MenuItem();
            this.Menu_Retrieve = new MenuItem();
            this.Menu_SendSelected = new MenuItem();
            this.Menu_SendAll = new MenuItem();
            this.menuItem17 = new MenuItem();
            this.Menu_DisplayNormal = new MenuItem();
            this.Menu_FlipHorizontal = new MenuItem();
            this.Menu_FlipVertical = new MenuItem();
            this.Menu_RotateClockwise = new MenuItem();
            this.Menu_RotateAntiClockwise = new MenuItem();
            this.menuItem2 = new MenuItem();
            this.Menu_CineModeForward = new MenuItem();
            this.Menu_CineModeRepeat = new MenuItem();
            this.Menu_CineModeOscillate = new MenuItem();
            this.Menu_CineModeRepeatReverse = new MenuItem();
            this.Menu_CineModeReverse = new MenuItem();
            this.Menu_CineModeStatic = new MenuItem();
            this.menuItem23 = new MenuItem();
            this.Menu_ViewImageInformation = new MenuItem();
            this.Menu_ViewOption = new MenuItem();
            this.menuItem26 = new MenuItem();
            this.Menu_ShowLoggingOptions = new MenuItem();
            this.menuItem28 = new MenuItem();
            this.Menu_MakeNewImage = new MenuItem();
            this.Menu_AboutThisExample = new MenuItem();
            this.Displayvalues = new Label();
            this.PatientName = new TextBox();
            this.groupBox1 = new GroupBox();
            this.StretchToFit = new CheckBox();
            this.Zoom1 = new TextBox();
            this.Width1 = new TextBox();
            this.ZoomLabel = new Label();
            this.WidthLabel = new Label();
            this.LevelLabel = new Label();
            this.Level1 = new TextBox();
            this.ZoomSlider = new TrackBar();
            this.WidthSlider = new TrackBar();
            this.LevelSlider = new TrackBar();
            this.groupBox2 = new GroupBox();
            this.PixelBTN = new RadioButton();
            this.MeasureBTN = new RadioButton();
            this.ProtractorBTN = new RadioButton();
            this.CobbBTN = new RadioButton();
            this.CropBTN = new RadioButton();
            this.MagnifyBTN = new RadioButton();
            this.EditAnnoBTN = new RadioButton();
            this.AddAnnoBTN = new RadioButton();
            this.ScrollBTN = new RadioButton();
            this.WindowBTN = new RadioButton();
            this.SelectBTN = new RadioButton();
            this.label4 = new Label();
            this.label5 = new Label();
            this.label6 = new Label();
            this.CImageIndex = new NumericUpDown();
            this.Rows = new NumericUpDown();
            this.Columns = new NumericUpDown();
            this.AnatomicMarkers = new CheckBox();
            this.groupBox3 = new GroupBox();
            this.CubicSpine = new RadioButton();
            this.BSpine = new RadioButton();
            this.Replicate = new RadioButton();
            this.MovingAverage = new RadioButton();
            this.PixelValue = new RadioButton();
            this.label8 = new Label();
            this.label7 = new Label();
            this.openFileDialog1 = new OpenFileDialog();
            this.saveFileDialog1 = new SaveFileDialog();
            this.Viewer = new DicomObjects.DicomViewer();
            this.groupBox1.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.ZoomSlider)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.WidthSlider)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.LevelSlider)).BeginInit();
            this.groupBox2.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.CImageIndex)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Rows)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Columns)).BeginInit();
            this.groupBox3.SuspendLayout();
            this.SuspendLayout();
            // 
            // mainMenu1
            // 
            this.mainMenu1.MenuItems.AddRange(new MenuItem[] {
            this.menuItem1,
            this.menuItem9,
            this.menuItem12,
            this.menuItem17,
            this.menuItem23,
            this.menuItem26,
            this.menuItem28});
            // 
            // menuItem1
            // 
            this.menuItem1.Index = 0;
            this.menuItem1.MenuItems.AddRange(new MenuItem[] {
            this.Menu_ReadFiles,
            this.Menu_WriteFiles,
            this.Menu_PrintDICOM,
            this.Menu_PrintWindows,
            this.Menu_Import,
            this.Menu_Export,
            this.menuItem8});
            this.menuItem1.Text = "File";
            // 
            // Menu_ReadFiles
            // 
            this.Menu_ReadFiles.Index = 0;
            this.Menu_ReadFiles.Text = "Read File(s)";
            this.Menu_ReadFiles.Click += new System.EventHandler(this.Menu_ReadFiles_Click);
            // 
            // Menu_WriteFiles
            // 
            this.Menu_WriteFiles.Index = 1;
            this.Menu_WriteFiles.Text = "Write File";
            this.Menu_WriteFiles.Click += new System.EventHandler(this.Menu_WriteFiles_Click);
            // 
            // Menu_PrintDICOM
            // 
            this.Menu_PrintDICOM.Index = 2;
            this.Menu_PrintDICOM.Text = "Print (DICOM)";
            this.Menu_PrintDICOM.Click += new System.EventHandler(this.Menu_PrintDICOM_Click);
            // 
            // Menu_PrintWindows
            // 
            this.Menu_PrintWindows.Index = 3;
            this.Menu_PrintWindows.Text = "Print (Windows)";
            this.Menu_PrintWindows.Click += new System.EventHandler(this.Menu_PrintWindows_Click);
            // 
            // Menu_Import
            // 
            this.Menu_Import.Index = 4;
            this.Menu_Import.Text = "Import Non-DICOM File";
            this.Menu_Import.Click += new System.EventHandler(this.Menu_Import_Click);
            // 
            // Menu_Export
            // 
            this.Menu_Export.Index = 5;
            this.Menu_Export.Text = "Export to Non-DICOM File";
            this.Menu_Export.Click += new System.EventHandler(this.Menu_Export_Click);
            // 
            // menuItem8
            // 
            this.menuItem8.Index = 6;
            this.menuItem8.Text = "Exit";
            this.menuItem8.Click += new System.EventHandler(this.MenuItem8_Click);
            // 
            // menuItem9
            // 
            this.menuItem9.Index = 1;
            this.menuItem9.MenuItems.AddRange(new MenuItem[] {
            this.Menu_DeleteSelected,
            this.Menu_DeleteAll});
            this.menuItem9.Text = "Edit";
            // 
            // Menu_DeleteSelected
            // 
            this.Menu_DeleteSelected.Index = 0;
            this.Menu_DeleteSelected.Text = "Delete Selected";
            this.Menu_DeleteSelected.Click += new System.EventHandler(this.Menu_DeleteSelected_Click);
            // 
            // Menu_DeleteAll
            // 
            this.Menu_DeleteAll.Index = 1;
            this.Menu_DeleteAll.Text = "Delete All";
            this.Menu_DeleteAll.Click += new System.EventHandler(this.Menu_DeleteAll_Click);
            // 
            // menuItem12
            // 
            this.menuItem12.Index = 2;
            this.menuItem12.MenuItems.AddRange(new MenuItem[] {
            this.Menu_Verify,
            this.Menu_Retrieve,
            this.Menu_SendSelected,
            this.Menu_SendAll});
            this.menuItem12.Text = "Remote";
            // 
            // Menu_Verify
            // 
            this.Menu_Verify.Index = 0;
            this.Menu_Verify.Text = "Verify";
            this.Menu_Verify.Click += new System.EventHandler(this.Menu_Verify_Click);
            // 
            // Menu_Retrieve
            // 
            this.Menu_Retrieve.Index = 1;
            this.Menu_Retrieve.Text = "Retrieve";
            this.Menu_Retrieve.Click += new System.EventHandler(this.Menu_Retrieve_Click);
            // 
            // Menu_SendSelected
            // 
            this.Menu_SendSelected.Index = 2;
            this.Menu_SendSelected.Text = "Send Selected";
            this.Menu_SendSelected.Click += new System.EventHandler(this.Menu_SendSelected_Click);
            // 
            // Menu_SendAll
            // 
            this.Menu_SendAll.Index = 3;
            this.Menu_SendAll.Text = "Send All";
            this.Menu_SendAll.Click += new System.EventHandler(this.Menu_SendAll_Click);
            // 
            // menuItem17
            // 
            this.menuItem17.Index = 3;
            this.menuItem17.MenuItems.AddRange(new MenuItem[] {
            this.Menu_DisplayNormal,
            this.Menu_FlipHorizontal,
            this.Menu_FlipVertical,
            this.Menu_RotateClockwise,
            this.Menu_RotateAntiClockwise,
            this.menuItem2});
            this.menuItem17.Text = "Display";
            // 
            // Menu_DisplayNormal
            // 
            this.Menu_DisplayNormal.Index = 0;
            this.Menu_DisplayNormal.Text = "Normal";
            this.Menu_DisplayNormal.Click += new System.EventHandler(this.Menu_DisplayNormal_Click);
            // 
            // Menu_FlipHorizontal
            // 
            this.Menu_FlipHorizontal.Index = 1;
            this.Menu_FlipHorizontal.Text = "Flip Horizontal";
            this.Menu_FlipHorizontal.Click += new System.EventHandler(this.Menu_FlipHorizontal_Click);
            // 
            // Menu_FlipVertical
            // 
            this.Menu_FlipVertical.Index = 2;
            this.Menu_FlipVertical.Text = "Flip Vertical";
            this.Menu_FlipVertical.Click += new System.EventHandler(this.Menu_FlipVertical_Click);
            // 
            // Menu_RotateClockwise
            // 
            this.Menu_RotateClockwise.Index = 3;
            this.Menu_RotateClockwise.Text = "Rotate Clockwise";
            this.Menu_RotateClockwise.Click += new System.EventHandler(this.Menu_RotateClockwise_Click);
            // 
            // Menu_RotateAntiClockwise
            // 
            this.Menu_RotateAntiClockwise.Index = 4;
            this.Menu_RotateAntiClockwise.Text = "Rotate Anti-Clockwise";
            this.Menu_RotateAntiClockwise.Click += new System.EventHandler(this.Menu_RotateAntiClockwise_Click);
            // 
            // menuItem2
            // 
            this.menuItem2.Index = 5;
            this.menuItem2.MenuItems.AddRange(new MenuItem[] {
            this.Menu_CineModeForward,
            this.Menu_CineModeRepeat,
            this.Menu_CineModeOscillate,
            this.Menu_CineModeRepeatReverse,
            this.Menu_CineModeReverse,
            this.Menu_CineModeStatic});
            this.menuItem2.Text = "CineMode";
            // 
            // Menu_CineModeForward
            // 
            this.Menu_CineModeForward.Index = 0;
            this.Menu_CineModeForward.Text = "Forward";
            this.Menu_CineModeForward.Click += new System.EventHandler(this.Menu_CineModeForward_Click);
            // 
            // Menu_CineModeRepeat
            // 
            this.Menu_CineModeRepeat.Index = 1;
            this.Menu_CineModeRepeat.Text = "Repeat";
            this.Menu_CineModeRepeat.Click += new System.EventHandler(this.Menu_CineModeRepeat_Click);
            // 
            // Menu_CineModeOscillate
            // 
            this.Menu_CineModeOscillate.Index = 2;
            this.Menu_CineModeOscillate.Text = "Oscillate";
            this.Menu_CineModeOscillate.Click += new System.EventHandler(this.Menu_CineModeOscillate_Click);
            // 
            // Menu_CineModeRepeatReverse
            // 
            this.Menu_CineModeRepeatReverse.Index = 3;
            this.Menu_CineModeRepeatReverse.Text = "RepeatReverse";
            this.Menu_CineModeRepeatReverse.Click += new System.EventHandler(this.Menu_CineModeRepeatReverse_Click);
            // 
            // Menu_CineModeReverse
            // 
            this.Menu_CineModeReverse.Index = 4;
            this.Menu_CineModeReverse.Text = "Reverse";
            this.Menu_CineModeReverse.Click += new System.EventHandler(this.Menu_CineModeReverse_Click);
            // 
            // Menu_CineModeStatic
            // 
            this.Menu_CineModeStatic.Index = 5;
            this.Menu_CineModeStatic.Text = "Static";
            this.Menu_CineModeStatic.Click += new System.EventHandler(this.Menu_CineModeStatic_Click);
            // 
            // menuItem23
            // 
            this.menuItem23.Index = 4;
            this.menuItem23.MenuItems.AddRange(new MenuItem[] {
            this.Menu_ViewImageInformation,
            this.Menu_ViewOption});
            this.menuItem23.Text = "View";
            // 
            // Menu_ViewImageInformation
            // 
            this.Menu_ViewImageInformation.Index = 0;
            this.Menu_ViewImageInformation.Text = "Image Information";
            this.Menu_ViewImageInformation.Click += new System.EventHandler(this.Menu_ViewImageInformation_Click);
            // 
            // Menu_ViewOption
            // 
            this.Menu_ViewOption.Index = 1;
            this.Menu_ViewOption.Text = "Options";
            this.Menu_ViewOption.Click += new System.EventHandler(this.Menu_ViewOption_Click);
            // 
            // menuItem26
            // 
            this.menuItem26.Index = 5;
            this.menuItem26.MenuItems.AddRange(new MenuItem[] {
            this.Menu_ShowLoggingOptions});
            this.menuItem26.Text = "Logging";
            // 
            // Menu_ShowLoggingOptions
            // 
            this.Menu_ShowLoggingOptions.Index = 0;
            this.Menu_ShowLoggingOptions.Text = "Show Logging Options";
            this.Menu_ShowLoggingOptions.Click += new System.EventHandler(this.Menu_ShowLoggingOptions_Click);
            // 
            // menuItem28
            // 
            this.menuItem28.Index = 6;
            this.menuItem28.MenuItems.AddRange(new MenuItem[] {
            this.Menu_MakeNewImage,
            this.Menu_AboutThisExample});
            this.menuItem28.Text = "Tools";
            // 
            // Menu_MakeNewImage
            // 
            this.Menu_MakeNewImage.Index = 0;
            this.Menu_MakeNewImage.Text = "Make new Image";
            this.Menu_MakeNewImage.Click += new System.EventHandler(this.Menu_MakeNewImage_Click);
            // 
            // Menu_AboutThisExample
            // 
            this.Menu_AboutThisExample.Index = 1;
            this.Menu_AboutThisExample.Text = "About This Example";
            this.Menu_AboutThisExample.Click += new System.EventHandler(this.Menu_AboutThisExample_Click);
            // 
            // Displayvalues
            // 
            this.Displayvalues.BackColor = System.Drawing.SystemColors.ControlDark;
            this.Displayvalues.Location = new System.Drawing.Point(8, 480);
            this.Displayvalues.Name = "Displayvalues";
            this.Displayvalues.Size = new System.Drawing.Size(496, 24);
            this.Displayvalues.TabIndex = 1;
            // 
            // PatientName
            // 
            this.PatientName.Location = new System.Drawing.Point(536, 8);
            this.PatientName.Name = "PatientName";
            this.PatientName.Size = new System.Drawing.Size(232, 20);
            this.PatientName.TabIndex = 2;
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.StretchToFit);
            this.groupBox1.Controls.Add(this.Zoom1);
            this.groupBox1.Controls.Add(this.Width1);
            this.groupBox1.Controls.Add(this.ZoomLabel);
            this.groupBox1.Controls.Add(this.WidthLabel);
            this.groupBox1.Controls.Add(this.LevelLabel);
            this.groupBox1.Controls.Add(this.Level1);
            this.groupBox1.Controls.Add(this.ZoomSlider);
            this.groupBox1.Controls.Add(this.WidthSlider);
            this.groupBox1.Controls.Add(this.LevelSlider);
            this.groupBox1.Location = new System.Drawing.Point(528, 40);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(248, 288);
            this.groupBox1.TabIndex = 3;
            this.groupBox1.TabStop = false;
            this.groupBox1.Text = "Display Settings";
            // 
            // StretchToFit
            // 
            this.StretchToFit.Checked = true;
            this.StretchToFit.CheckState = CheckState.Checked;
            this.StretchToFit.Location = new System.Drawing.Point(72, 264);
            this.StretchToFit.Name = "StretchToFit";
            this.StretchToFit.Size = new System.Drawing.Size(96, 16);
            this.StretchToFit.TabIndex = 9;
            this.StretchToFit.Text = "Stretch To Fit";
            this.StretchToFit.Visible = false;
            this.StretchToFit.CheckedChanged += new System.EventHandler(this.StretchToFit_CheckedChanged);
            // 
            // Zoom1
            // 
            this.Zoom1.Location = new System.Drawing.Point(168, 232);
            this.Zoom1.Name = "Zoom1";
            this.Zoom1.Size = new System.Drawing.Size(48, 20);
            this.Zoom1.TabIndex = 8;
            this.Zoom1.Text = "1.0";
            this.Zoom1.Visible = false;
            // 
            // Width1
            // 
            this.Width1.Location = new System.Drawing.Point(88, 232);
            this.Width1.Name = "Width1";
            this.Width1.Size = new System.Drawing.Size(48, 20);
            this.Width1.TabIndex = 7;
            this.Width1.Visible = false;
            // 
            // ZoomLabel
            // 
            this.ZoomLabel.AutoSize = true;
            this.ZoomLabel.Location = new System.Drawing.Point(176, 24);
            this.ZoomLabel.Name = "ZoomLabel";
            this.ZoomLabel.Size = new System.Drawing.Size(34, 13);
            this.ZoomLabel.TabIndex = 6;
            this.ZoomLabel.Text = "Zoom";
            this.ZoomLabel.Visible = false;
            // 
            // WidthLabel
            // 
            this.WidthLabel.AutoSize = true;
            this.WidthLabel.Location = new System.Drawing.Point(96, 24);
            this.WidthLabel.Name = "WidthLabel";
            this.WidthLabel.Size = new System.Drawing.Size(35, 13);
            this.WidthLabel.TabIndex = 5;
            this.WidthLabel.Text = "Width";
            this.WidthLabel.Visible = false;
            // 
            // LevelLabel
            // 
            this.LevelLabel.AutoSize = true;
            this.LevelLabel.Location = new System.Drawing.Point(16, 24);
            this.LevelLabel.Name = "LevelLabel";
            this.LevelLabel.Size = new System.Drawing.Size(33, 13);
            this.LevelLabel.TabIndex = 4;
            this.LevelLabel.Text = "Level";
            this.LevelLabel.Visible = false;
            // 
            // Level1
            // 
            this.Level1.Location = new System.Drawing.Point(8, 232);
            this.Level1.Name = "Level1";
            this.Level1.Size = new System.Drawing.Size(48, 20);
            this.Level1.TabIndex = 3;
            this.Level1.Visible = false;
            // 
            // ZoomSlider
            // 
            this.ZoomSlider.Location = new System.Drawing.Point(176, 40);
            this.ZoomSlider.Maximum = 40;
            this.ZoomSlider.Minimum = -40;
            this.ZoomSlider.Name = "ZoomSlider";
            this.ZoomSlider.Orientation = Orientation.Vertical;
            this.ZoomSlider.Size = new System.Drawing.Size(45, 184);
            this.ZoomSlider.TabIndex = 2;
            this.ZoomSlider.TickFrequency = 50;
            this.ZoomSlider.Value = 1;
            this.ZoomSlider.Visible = false;
            this.ZoomSlider.Scroll += new System.EventHandler(this.ZoomSlider_Scroll);
            // 
            // WidthSlider
            // 
            this.WidthSlider.Location = new System.Drawing.Point(96, 40);
            this.WidthSlider.Maximum = 1000;
            this.WidthSlider.Name = "WidthSlider";
            this.WidthSlider.Orientation = Orientation.Vertical;
            this.WidthSlider.Size = new System.Drawing.Size(45, 184);
            this.WidthSlider.TabIndex = 1;
            this.WidthSlider.TickFrequency = 50;
            this.WidthSlider.Visible = false;
            this.WidthSlider.Scroll += new System.EventHandler(this.WidthSlider_Scroll);
            this.WidthSlider.MouseDown += new MouseEventHandler(this.WidthSlider_MouseDown);
            this.WidthSlider.MouseUp += new MouseEventHandler(this.WidthSlider_MouseUp);
            // 
            // LevelSlider
            // 
            this.LevelSlider.Location = new System.Drawing.Point(16, 40);
            this.LevelSlider.Maximum = 1000;
            this.LevelSlider.Name = "LevelSlider";
            this.LevelSlider.Orientation = Orientation.Vertical;
            this.LevelSlider.Size = new System.Drawing.Size(45, 184);
            this.LevelSlider.TabIndex = 0;
            this.LevelSlider.TickFrequency = 50;
            this.LevelSlider.Visible = false;
            this.LevelSlider.Scroll += new System.EventHandler(this.LevelSlider_Scroll);
            this.LevelSlider.MouseDown += new MouseEventHandler(this.LevelSlider_MouseDown);
            this.LevelSlider.MouseUp += new MouseEventHandler(this.LevelSlider_MouseUp);
            // 
            // groupBox2
            // 
            this.groupBox2.Controls.Add(this.PixelBTN);
            this.groupBox2.Controls.Add(this.MeasureBTN);
            this.groupBox2.Controls.Add(this.ProtractorBTN);
            this.groupBox2.Controls.Add(this.CobbBTN);
            this.groupBox2.Controls.Add(this.CropBTN);
            this.groupBox2.Controls.Add(this.MagnifyBTN);
            this.groupBox2.Controls.Add(this.EditAnnoBTN);
            this.groupBox2.Controls.Add(this.AddAnnoBTN);
            this.groupBox2.Controls.Add(this.ScrollBTN);
            this.groupBox2.Controls.Add(this.WindowBTN);
            this.groupBox2.Controls.Add(this.SelectBTN);
            this.groupBox2.Location = new System.Drawing.Point(512, 344);
            this.groupBox2.Name = "groupBox2";
            this.groupBox2.Size = new System.Drawing.Size(272, 216);
            this.groupBox2.TabIndex = 4;
            this.groupBox2.TabStop = false;
            this.groupBox2.Text = "Mouse Functions";
            // 
            // PixelBTN
            // 
            this.PixelBTN.Appearance = Appearance.Button;
            this.PixelBTN.Location = new System.Drawing.Point(104, 168);
            this.PixelBTN.Name = "PixelBTN";
            this.PixelBTN.Size = new System.Drawing.Size(70, 32);
            this.PixelBTN.TabIndex = 10;
            this.PixelBTN.Text = "Pixel Values";
            this.PixelBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.PixelBTN.CheckedChanged += new System.EventHandler(this.PixelBTN_CheckedChanged);
            // 
            // MeasureBTN
            // 
            this.MeasureBTN.Appearance = Appearance.Button;
            this.MeasureBTN.Location = new System.Drawing.Point(16, 168);
            this.MeasureBTN.Name = "MeasureBTN";
            this.MeasureBTN.Size = new System.Drawing.Size(70, 32);
            this.MeasureBTN.TabIndex = 9;
            this.MeasureBTN.Text = "Measure";
            this.MeasureBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.MeasureBTN.CheckedChanged += new System.EventHandler(this.MeasureBTN_CheckedChanged);
            // 
            // ProtractorBTN
            // 
            this.ProtractorBTN.Appearance = Appearance.Button;
            this.ProtractorBTN.Location = new System.Drawing.Point(192, 120);
            this.ProtractorBTN.Name = "ProtractorBTN";
            this.ProtractorBTN.Size = new System.Drawing.Size(70, 32);
            this.ProtractorBTN.TabIndex = 8;
            this.ProtractorBTN.Text = "Protractor";
            this.ProtractorBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.ProtractorBTN.CheckedChanged += new System.EventHandler(this.ProtractorBTN_CheckedChanged);
            // 
            // CobbBTN
            // 
            this.CobbBTN.Appearance = Appearance.Button;
            this.CobbBTN.Location = new System.Drawing.Point(104, 120);
            this.CobbBTN.Name = "CobbBTN";
            this.CobbBTN.Size = new System.Drawing.Size(70, 32);
            this.CobbBTN.TabIndex = 7;
            this.CobbBTN.Text = "Cobb";
            this.CobbBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.CobbBTN.CheckedChanged += new System.EventHandler(this.CobbBTN_CheckedChanged);
            // 
            // CropBTN
            // 
            this.CropBTN.Appearance = Appearance.Button;
            this.CropBTN.Location = new System.Drawing.Point(16, 120);
            this.CropBTN.Name = "CropBTN";
            this.CropBTN.Size = new System.Drawing.Size(70, 32);
            this.CropBTN.TabIndex = 6;
            this.CropBTN.Text = "Crop";
            this.CropBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.CropBTN.CheckedChanged += new System.EventHandler(this.CropBTN_CheckedChanged);
            // 
            // MagnifyBTN
            // 
            this.MagnifyBTN.Appearance = Appearance.Button;
            this.MagnifyBTN.Location = new System.Drawing.Point(192, 72);
            this.MagnifyBTN.Name = "MagnifyBTN";
            this.MagnifyBTN.Size = new System.Drawing.Size(70, 32);
            this.MagnifyBTN.TabIndex = 5;
            this.MagnifyBTN.Text = "Magnifing Glass";
            this.MagnifyBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.MagnifyBTN.CheckedChanged += new System.EventHandler(this.MagnifyBTN_CheckedChanged);
            // 
            // EditAnnoBTN
            // 
            this.EditAnnoBTN.Appearance = Appearance.Button;
            this.EditAnnoBTN.Location = new System.Drawing.Point(104, 72);
            this.EditAnnoBTN.Name = "EditAnnoBTN";
            this.EditAnnoBTN.Size = new System.Drawing.Size(70, 32);
            this.EditAnnoBTN.TabIndex = 4;
            this.EditAnnoBTN.Text = "Edit Annotation";
            this.EditAnnoBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.EditAnnoBTN.CheckedChanged += new System.EventHandler(this.EditAnnoBTN_CheckedChanged);
            // 
            // AddAnnoBTN
            // 
            this.AddAnnoBTN.Appearance = Appearance.Button;
            this.AddAnnoBTN.Location = new System.Drawing.Point(16, 72);
            this.AddAnnoBTN.Name = "AddAnnoBTN";
            this.AddAnnoBTN.Size = new System.Drawing.Size(70, 32);
            this.AddAnnoBTN.TabIndex = 3;
            this.AddAnnoBTN.Text = "Add Annotation";
            this.AddAnnoBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.AddAnnoBTN.CheckedChanged += new System.EventHandler(this.AddAnnoBTN_CheckedChanged);
            // 
            // ScrollBTN
            // 
            this.ScrollBTN.Appearance = Appearance.Button;
            this.ScrollBTN.Location = new System.Drawing.Point(192, 24);
            this.ScrollBTN.Name = "ScrollBTN";
            this.ScrollBTN.Size = new System.Drawing.Size(70, 32);
            this.ScrollBTN.TabIndex = 2;
            this.ScrollBTN.Text = "Scroll";
            this.ScrollBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.ScrollBTN.CheckedChanged += new System.EventHandler(this.ScrollBTN_CheckedChanged);
            // 
            // WindowBTN
            // 
            this.WindowBTN.Appearance = Appearance.Button;
            this.WindowBTN.Location = new System.Drawing.Point(104, 24);
            this.WindowBTN.Name = "WindowBTN";
            this.WindowBTN.Size = new System.Drawing.Size(70, 32);
            this.WindowBTN.TabIndex = 1;
            this.WindowBTN.Text = "Window";
            this.WindowBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.WindowBTN.CheckedChanged += new System.EventHandler(this.WindowBTN_CheckedChanged);
            // 
            // SelectBTN
            // 
            this.SelectBTN.Appearance = Appearance.Button;
            this.SelectBTN.Location = new System.Drawing.Point(16, 24);
            this.SelectBTN.Name = "SelectBTN";
            this.SelectBTN.Size = new System.Drawing.Size(70, 32);
            this.SelectBTN.TabIndex = 0;
            this.SelectBTN.Text = "Select";
            this.SelectBTN.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.SelectBTN.CheckedChanged += new System.EventHandler(this.SelectBTN_CheckedChanged);
            // 
            // label4
            // 
            this.label4.AutoSize = true;
            this.label4.Location = new System.Drawing.Point(16, 528);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(102, 13);
            this.label4.TabIndex = 5;
            this.label4.Text = "Current Image Index";
            // 
            // label5
            // 
            this.label5.AutoSize = true;
            this.label5.Location = new System.Drawing.Point(16, 584);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(71, 13);
            this.label5.TabIndex = 6;
            this.label5.Text = "Display Rows";
            // 
            // label6
            // 
            this.label6.AutoSize = true;
            this.label6.Location = new System.Drawing.Point(16, 616);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(84, 13);
            this.label6.TabIndex = 7;
            this.label6.Text = "Display Columns";
            // 
            // CImageIndex
            // 
            this.CImageIndex.Location = new System.Drawing.Point(144, 528);
            this.CImageIndex.Maximum = new decimal(new int[] {
            0,
            0,
            0,
            0});
            this.CImageIndex.Name = "CImageIndex";
            this.CImageIndex.Size = new System.Drawing.Size(40, 20);
            this.CImageIndex.TabIndex = 8;
            this.CImageIndex.MouseUp += new MouseEventHandler(this.CImageIndex_MouseUp);
            // 
            // Rows
            // 
            this.Rows.Location = new System.Drawing.Point(144, 584);
            this.Rows.Maximum = new decimal(new int[] {
            50,
            0,
            0,
            0});
            this.Rows.Minimum = new decimal(new int[] {
            1,
            0,
            0,
            0});
            this.Rows.Name = "Rows";
            this.Rows.Size = new System.Drawing.Size(40, 20);
            this.Rows.TabIndex = 9;
            this.Rows.Value = new decimal(new int[] {
            1,
            0,
            0,
            0});
            this.Rows.MouseUp += new MouseEventHandler(this.Rows_MouseUp);
            // 
            // Columns
            // 
            this.Columns.Location = new System.Drawing.Point(144, 616);
            this.Columns.Maximum = new decimal(new int[] {
            50,
            0,
            0,
            0});
            this.Columns.Minimum = new decimal(new int[] {
            1,
            0,
            0,
            0});
            this.Columns.Name = "Columns";
            this.Columns.Size = new System.Drawing.Size(40, 20);
            this.Columns.TabIndex = 10;
            this.Columns.Value = new decimal(new int[] {
            1,
            0,
            0,
            0});
            this.Columns.MouseUp += new MouseEventHandler(this.Columns_MouseUp);
            // 
            // AnatomicMarkers
            // 
            this.AnatomicMarkers.CheckAlign = System.Drawing.ContentAlignment.MiddleRight;
            this.AnatomicMarkers.Location = new System.Drawing.Point(16, 552);
            this.AnatomicMarkers.Name = "AnatomicMarkers";
            this.AnatomicMarkers.Size = new System.Drawing.Size(168, 16);
            this.AnatomicMarkers.TabIndex = 11;
            this.AnatomicMarkers.Text = "Show Anatomic Side Markers";
            this.AnatomicMarkers.CheckedChanged += new System.EventHandler(this.AnatomicMarkers_CheckedChanged);
            // 
            // groupBox3
            // 
            this.groupBox3.Controls.Add(this.CubicSpine);
            this.groupBox3.Controls.Add(this.BSpine);
            this.groupBox3.Controls.Add(this.Replicate);
            this.groupBox3.Controls.Add(this.MovingAverage);
            this.groupBox3.Controls.Add(this.PixelValue);
            this.groupBox3.Controls.Add(this.label8);
            this.groupBox3.Controls.Add(this.label7);
            this.groupBox3.Location = new System.Drawing.Point(192, 520);
            this.groupBox3.Name = "groupBox3";
            this.groupBox3.Size = new System.Drawing.Size(312, 120);
            this.groupBox3.TabIndex = 12;
            this.groupBox3.TabStop = false;
            this.groupBox3.Text = "Smoothing Settings";
            // 
            // CubicSpine
            // 
            this.CubicSpine.Appearance = Appearance.Button;
            this.CubicSpine.Location = new System.Drawing.Point(240, 72);
            this.CubicSpine.Name = "CubicSpine";
            this.CubicSpine.Size = new System.Drawing.Size(56, 32);
            this.CubicSpine.TabIndex = 6;
            this.CubicSpine.Text = "Cubic Spine";
            this.CubicSpine.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.CubicSpine.CheckedChanged += new System.EventHandler(this.CubicSpine_CheckedChanged);
            // 
            // BSpine
            // 
            this.BSpine.Appearance = Appearance.Button;
            this.BSpine.Location = new System.Drawing.Point(176, 72);
            this.BSpine.Name = "BSpine";
            this.BSpine.Size = new System.Drawing.Size(56, 32);
            this.BSpine.TabIndex = 5;
            this.BSpine.Text = "B-Spine";
            this.BSpine.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.BSpine.CheckedChanged += new System.EventHandler(this.BSpine_CheckedChanged);
            // 
            // Replicate
            // 
            this.Replicate.Appearance = Appearance.Button;
            this.Replicate.Location = new System.Drawing.Point(88, 72);
            this.Replicate.Name = "Replicate";
            this.Replicate.Size = new System.Drawing.Size(80, 32);
            this.Replicate.TabIndex = 4;
            this.Replicate.Text = "Pixel Value";
            this.Replicate.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.Replicate.CheckedChanged += new System.EventHandler(this.Replicate_CheckedChanged);
            // 
            // MovingAverage
            // 
            this.MovingAverage.Appearance = Appearance.Button;
            this.MovingAverage.Location = new System.Drawing.Point(208, 16);
            this.MovingAverage.Name = "MovingAverage";
            this.MovingAverage.Size = new System.Drawing.Size(88, 40);
            this.MovingAverage.TabIndex = 3;
            this.MovingAverage.Text = "Moving Average";
            this.MovingAverage.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.MovingAverage.CheckedChanged += new System.EventHandler(this.MovingAverage_CheckedChanged);
            // 
            // PixelValue
            // 
            this.PixelValue.Appearance = Appearance.Button;
            this.PixelValue.Location = new System.Drawing.Point(96, 16);
            this.PixelValue.Name = "PixelValue";
            this.PixelValue.Size = new System.Drawing.Size(88, 40);
            this.PixelValue.TabIndex = 2;
            this.PixelValue.Text = "Pixel Value";
            this.PixelValue.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.PixelValue.CheckedChanged += new System.EventHandler(this.PixelValue_CheckedChanged);
            // 
            // label8
            // 
            this.label8.AutoSize = true;
            this.label8.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.5F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label8.Location = new System.Drawing.Point(7, 80);
            this.label8.Name = "label8";
            this.label8.Size = new System.Drawing.Size(94, 15);
            this.label8.TabIndex = 1;
            this.label8.Text = "Magnification";
            // 
            // label7
            // 
            this.label7.AutoSize = true;
            this.label7.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.5F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label7.Location = new System.Drawing.Point(8, 28);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(82, 15);
            this.label7.TabIndex = 0;
            this.label7.Text = "Minification";
            // 
            // openFileDialog1
            // 
            this.openFileDialog1.Multiselect = true;
            // 
            // Viewer
            // 
            this.Viewer.AutoDisplay = false;
            this.Viewer.BackColor = System.Drawing.Color.Black;
            this.Viewer.BackColour = System.Drawing.Color.Black;
            this.Viewer.Border = ((short)(0));
            this.Viewer.CellSpacing = ((short)(0));
            this.Viewer.CurrentIndex = 0;
            this.Viewer.HitMargin = 3;
            this.Viewer.Location = new System.Drawing.Point(7, 12);
            this.Viewer.MultiColumns = ((short)(1));
            this.Viewer.MultiRows = ((short)(1));
            this.Viewer.Name = "Viewer";
            this.Viewer.PixelSize = new System.Drawing.SizeF(0.3F, 0.3F);
            this.Viewer.ShowLabels = true;
            this.Viewer.Size = new System.Drawing.Size(497, 465);
            this.Viewer.TabIndex = 13;
            this.Viewer.Text = "dicomViewer1";
            this.Viewer.MouseMove += new MouseEventHandler(this.Viewer_MouseMove);
            this.Viewer.DataChanged += new DicomObjects.Delegates.DataChangedHandler(Viewer_DataChanged);
            this.Viewer.MouseDown += new MouseEventHandler(this.Viewer_MouseDown);
            this.Viewer.MouseUp += new MouseEventHandler(this.Viewer_MouseUp);
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(792, 649);
            this.Controls.Add(this.Viewer);
            this.Controls.Add(this.groupBox3);
            this.Controls.Add(this.AnatomicMarkers);
            this.Controls.Add(this.Columns);
            this.Controls.Add(this.Rows);
            this.Controls.Add(this.CImageIndex);
            this.Controls.Add(this.label6);
            this.Controls.Add(this.label5);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.PatientName);
            this.Controls.Add(this.groupBox2);
            this.Controls.Add(this.groupBox1);
            this.Controls.Add(this.Displayvalues);
            //this.FormBorderStyle = FormBorderStyle.FixedSingle;
            this.MaximizeBox = false;
            this.Menu = this.mainMenu1;
            this.Name = "Form1";
            this.Text = "DicomViewer C# - DicomObjects.NET";
            this.Load += new System.EventHandler(this.Form1_Load);
            this.FormClosing += new FormClosingEventHandler(this.Form1_FormClosing);
            this.groupBox1.ResumeLayout(false);
            this.groupBox1.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.ZoomSlider)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.WidthSlider)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.LevelSlider)).EndInit();
            this.groupBox2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.CImageIndex)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Rows)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Columns)).EndInit();
            this.groupBox3.ResumeLayout(false);
            this.groupBox3.PerformLayout();
            this.ResumeLayout(false);
            this.PerformLayout();

        }
        #endregion

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            Application.Run(new Form1());
        }

        private void SelectBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (SelectBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.SelectImage;
            }
        }

        private void WindowBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (WindowBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.Windowing;
            }
        }

        private void ScrollBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (ScrollBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.Scroll;
            }
        }

        private void AddAnnoBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (AddAnnoBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.AddAnnotation;
                LabelUpdate();
            }
        }

        private void LabelUpdate()
        {
            LabelForm.ShowDialog();
            if (MouseFunction == MouseFunctionEnums.Measure)
            {
                LabelForm.ImageScale.Checked = true;
            }
        }

        private void EditAnnoBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (EditAnnoBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.EditAnnotation;
            }
        }

        private void MagnifyBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (MagnifyBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.MagnifyingGlass;
            }
        }

        private void CropBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (CropBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.CropImage;
            }
        }

        private void CobbBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (CobbBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.CobbMeasurement;
            }
            ClickNum = 1;
        }

        private void ProtractorBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (ProtractorBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.Protractor;
            }
            ClickNum = 1;
        }

        private void MeasureBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (MeasureBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.Measure;
                LabelUpdate();
            }
        }

        private void PixelBTN_CheckedChanged(object sender, EventArgs e)
        {
            if (PixelBTN.Checked)
            {
                MouseFunction = MouseFunctionEnums.PixelValues;
            }
        }

        private DicomImage GetSelectedImage()
        {
            if (isSelectedImage)
                return SelectedImage;

            if (Viewer.Images.Count > 0)
                return Viewer.CurrentImage;

            MessageBox.Show("No Image to Manipulate!");
            SelectedImage = new DicomImage();
            isSelectedImage = true;
            return SelectedImage;
        }

        private void Menu_ReadFiles_Click(object sender, EventArgs e)
        {
            openFileDialog1.InitialDirectory = Path.Combine(Directory.GetParent(Directory.GetParent(Directory.GetParent(Directory.GetParent(
                Directory.GetParent(Environment.CurrentDirectory).ToString()).ToString()).ToString()).ToString()).ToString(), "Sample Images");
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                foreach (string filename in openFileDialog1.FileNames)
                {
                    Viewer.Images.Read(filename);
                }
                CImageIndex.Maximum = Viewer.Images.Count - 1;
                CImageIndex.Minimum = 0;
            }
        }

        private void Menu_WriteFiles_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                GetSelectedImage().Write(saveFileDialog1.FileName, "1.2.840.10008.1.2.1");
            }
        }

        private void Menu_PrintDICOM_Click(object sender, EventArgs e)
        {
            DicomPrint printer = new DicomPrint
            {
                Colour = OptionsBox.PrintInColour.Checked,
                Format = OptionsBox.PrintFormat.Text,
                Orientation = OptionsBox.PrintOrientation.Text,
                FilmSize = OptionsBox.FilmSize.Text
            };

            printer.Open(OptionsBox.PrintNode.Text, Convert.ToInt32(OptionsBox.PrintPort.Text), OptionsBox.PrintAE.Text, OptionsBox.PrintCallingAE.Text);
            printer.FilmBox.Add(0x2010, 0x0060, OptionsBox.Magnification.Text);

            //  Sending all images loaded on Viewer for printing
            foreach (DicomImage img in Viewer.Images)
                printer.PrintImage(img, true, true);
            printer.Close();
        }

        private void Menu_PrintWindows_Click(object sender, EventArgs e)
        {
            printDoc = new System.Drawing.Printing.PrintDocument();
            printDoc.PrintPage += PrintDoc_PrintPage;
            printDoc.OriginAtMargins = false;
            printDoc.DefaultPageSettings.Landscape = true;
            printDoc.PrinterSettings.Copies = 1;
            printDoc.Print();
        }

        private void PrintDoc_PrintPage(object sender, System.Drawing.Printing.PrintPageEventArgs e)
        {
            DicomImage pImage;
            Rectangle area = new Rectangle(0, 0, 0, 0);
            int Bits = Convert.ToInt16(Viewer.CurrentImage.DataSet[0x0028, 0x0100].Value);
            pImage = Viewer.CurrentImage.PrinterImage(Bits, 1, true, 0.7f, area, true);
            Image printImage = pImage.Bitmap();
            e.Graphics.DrawImage(printImage, 0, 0);
        }

        private void Menu_Import_Click(object sender, EventArgs e)
        {
            openFileDialog1.FileName = "";
            openFileDialog1.Filter = "Images & Cine (*.bmp,*.dib,*.jpg,*.avi,*.tif,*.mpg, *.j2k)|*.bmp;.dib;*.jpg;*.avi;*.tif;*.mpg; *.j2k";
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                DicomImage image = new DicomImage();
                image.Import(openFileDialog1.FileName);
                Viewer.Images.Add(image);
            }
        }

        private void Menu_Export_Click(object sender, EventArgs e)
        {
            string filename;
            saveFileDialog1.FileName = "";

            if (GetSelectedImage().FrameCount > 1)
            {
                saveFileDialog1.Filter = "AVI (*.avi)|*.avi|Windows Bitmap(*.bmp)|*.bmp|Jpeg(*.jpg)|*.jpg";
            }
            else
            {
                saveFileDialog1.Filter = "Windows Bitmap(*.bmp)|*.bmp|Jpeg(*.jpg)|*.jpg";
            }

            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                filename = saveFileDialog1.FileName;
                if (filename.Substring(filename.Length - 3, 3) == "AVI")
                {
                    //TODO
                    // export AVI file
                }
                else
                {
                    // Save as JPEG for example
                    GetSelectedImage().Bitmap().Save(filename, System.Drawing.Imaging.ImageFormat.Jpeg);
                }
            }
        }

        private void MenuItem8_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void LevelSlider_Scroll(object sender, EventArgs e)
        {
            if (OptionsBox.WindowAll.Checked)
            {
                for (int i = 0; i < Viewer.Images.Count; i++)
                {
                    Viewer.Images[i].Level = LevelSlider.Value;
                }
            }
            else
            {
                GetSelectedImage().Level = LevelSlider.Value;
            }
            Level1.Text = LevelSlider.Value.ToString();
        }

        private void WidthSlider_Scroll(object sender, EventArgs e)
        {
            if (OptionsBox.WindowAll.Checked)
            {
                foreach (DicomImage t in Viewer.Images)
                {
                    t.Width = WidthSlider.Value;
                }
            }
            else
            {
                GetSelectedImage().Width = WidthSlider.Value;
            }
            Width1.Text = WidthSlider.Value.ToString();
        }

        private void ZoomSlider_Scroll(object sender, EventArgs e)
        {
            double z;
            z = Math.Pow(2, ZoomSlider.Value / (double)10);
            Zoom1.Text = z.ToString();
            Zoom1.Refresh();
            GetSelectedImage().Zoom = (float)z;
        }

        private void Menu_DeleteSelected_Click(object sender, EventArgs e)
        {
            if (Viewer.Images.Count > 0)
            {
                if (CImageIndex.Value > 0)
                {
                    CImageIndex.Value--;
                }
                else
                {
                    CImageIndex.Value = 0;
                }
                CImageIndex.Maximum = Viewer.Images.Count - 1;
                Viewer.Images.Remove(GetSelectedImage());
                SelectedImage = null;
                isSelectedImage = false;
            }
        }

        private void Menu_DeleteAll_Click(object sender, EventArgs e)
        {
            Viewer.Images.Clear();
            CImageIndex.Maximum = 0;
            WidthSlider.Visible = false;
            WidthLabel.Visible = false;
            Width1.Visible = false;
            LevelSlider.Visible = false;
            LevelLabel.Visible = false;
            Level1.Visible = false;
            ZoomSlider.Visible = false;
            Zoom1.Visible = false;
            ZoomLabel.Visible = false;
            StretchToFit.Visible = false;
            PatientName.Text = "";
            Viewer.Refresh();
        }

        private void Menu_Verify_Click(object sender, EventArgs e)
        {
            int result;
            result = DicomGlobal.Echo(OptionsBox.StorageNode.Text, Convert.ToInt32(OptionsBox.StoragePort.Text), OptionsBox.CallingAE.Text, OptionsBox.StorageAE.Text);
            MessageBox.Show("Verify Returned Status --- " + result.ToString());
        }

        private void Menu_Retrieve_Click(object sender, EventArgs e)
        {
            RetrieveBox.LoadPatient(OptionsBox, Viewer);
        }

        private void Menu_SendSelected_Click(object sender, EventArgs e)
        {
            int Status;
            if (GetSelectedImage().Pixels != null)
            {
                Status = GetSelectedImage().Send(OptionsBox.StorageNode.Text, Convert.ToInt32(OptionsBox.StoragePort.Text), OptionsBox.CallingAE.Text, OptionsBox.StorageAE.Text);
                MessageBox.Show("Returned Status = " + Status.ToString());
            }
        }

        private void Menu_SendAll_Click(object sender, EventArgs e)
        {
            int Status;

            if (Viewer.Images.Count == 0)
            {
                MessageBox.Show("No Images to Manipulate");
            }
            else
            {
                for (int i = 0; i < Viewer.Images.Count; i++)
                {
                    Status = Viewer.Images[i].Send(OptionsBox.StorageNode.Text, Convert.ToInt32(OptionsBox.StoragePort.Text), OptionsBox.CallingAE.Text, OptionsBox.StorageAE.Text);
                    if (Status != 0)
                    {
                        MessageBox.Show("Send Failed - Returned Status = " + Status.ToString());
                    }
                }
            }
        }

        private void Menu_DisplayNormal_Click(object sender, EventArgs e)
        {
            GetSelectedImage().RotateState = DicomObjects.Enums.RotateState.Normal;
            GetSelectedImage().FlipState = DicomObjects.Enums.FlipState.Normal;
        }

        private void Menu_FlipHorizontal_Click(object sender, EventArgs e)
        {
            GetSelectedImage().FlipState = (DicomObjects.Enums.FlipState)((int)GetSelectedImage().FlipState ^ (int)DicomObjects.Enums.FlipState.Horizontal);
        }

        private void Menu_FlipVertical_Click(object sender, EventArgs e)
        {
            GetSelectedImage().FlipState = (DicomObjects.Enums.FlipState)((int)GetSelectedImage().FlipState ^ (int)DicomObjects.Enums.FlipState.Vertical);
        }

        private void Menu_RotateClockwise_Click(object sender, EventArgs e)
        {
            GetSelectedImage().RotateState = (DicomObjects.Enums.RotateState)((int)GetSelectedImage().RotateState + (int)DicomObjects.Enums.RotateState.Right);
        }

        private void Menu_RotateAntiClockwise_Click(object sender, EventArgs e)
        {
            GetSelectedImage().RotateState = (DicomObjects.Enums.RotateState)((int)GetSelectedImage().RotateState + (int)DicomObjects.Enums.RotateState.Left);
        }

        private void AppendAttributes(System.Text.StringBuilder list, string prefix, DicomObjects.DicomDataSet ob)
        {
            DicomAttribute at;
            DicomDataSetCollection s;
            int i;
            object v;

            for (int j = 0; j < ob.Count; j++)
            {
                at = ob[j];
                list.Append(prefix).Append("(").Append(at.Group.ToString("X4")).Append(",").Append(at.Element.ToString("X4")).Append(") : ");
                list.Append(at.Description.PadRight(30)).Append(": ");
                if ((at.Group == 0x7FE0)) // pixel data;

                    list.Append("Pixel data").Append("\r\n");
                else
                {
                    if (at.Value is DicomDataSetCollection)  // i.e. a sequence;
                    {
                        s = at.Value as DicomDataSetCollection;
                        if (s != null)
                        {
                            list.Append("Sequence of ").Append(s.Count).Append(" items:").Append("\r\n");
                            for (i = 0; i < s.Count; i++)
                            {
                                list.Append(prefix).Append(">---------------").Append("\r\n");
                                AppendAttributes(list, prefix + ">", s[i]);
                            }
                            list.Append(prefix).Append(">---------------");
                            list.Append("\r\n");
                        }
                        else
                        {
                            list.Append("\r\n");
                        }
                    }
                    else
                    {
                        v = at.Value; // could be variant or array;
                        if (v is Array)  // i.e. an array;
                        {
                            Array a = v as Array;
                            list.Append("Multiple values :");
                            list.Append("\r\n");
                            list.Append("              ");

                            if (a.Length > 32)
                            {
                                list.Append("Array of ").Append(a.Length.ToString()).Append(" elements");
                            }
                            else
                            {
                                for (i = 0; i < a.Length; i++)
                                {
                                    list.Append(a.GetValue(i));
                                    if (i != a.Length - 1) list.Append(" : ");
                                }
                            }
                            list.Append("\r\n");
                        }
                        else
                        {
                            if (at.VR == "DA" && v != null)
                            {
                                DateTime d = (DateTime)v;
                                list.AppendLine(d.ToShortDateString());
                            }
                            else
                            {
                                if (at.VR == "TM" && v != null)
                                {
                                    DateTime d = (DateTime)v;
                                    list.AppendLine(d.ToShortTimeString());
                                }
                                else
                                {
                                    list.AppendLine((v == null) ? "" : v.ToString());
                                }
                            }
                        }
                    }
                }
            }
        }

        private void NewData()
        {
            System.Text.StringBuilder strBuilder = new System.Text.StringBuilder(256);
            AttributeForm.AttributeList.Text = "";
            if (Viewer.Images.Count > 0)
            {
                AppendAttributes(strBuilder, "", GetSelectedImage().DataSet);
                AttributeForm.AttributeList.Text = strBuilder.ToString();
            }
            else
            {
                AttributeForm.AttributeList.Text = "No Image Available";
            }
        }

        private void Menu_ViewImageInformation_Click(object sender, EventArgs e)
        {
            NewData();
            AttributeForm.ShowDialog();
        }

        private void Menu_ViewOption_Click(object sender, EventArgs e)
        {
            OptionsBox.ServerOpt = server;
            OptionsBox.tabControl1.SelectedTab = OptionsBox.tabControl1.TabPages[3];
            OptionsBox.ShowDialog();
        }

        private void Menu_ShowLoggingOptions_Click(object sender, EventArgs e)
        {
            OptionsBox.ServerOpt = server;
            OptionsBox.tabControl1.SelectedTab = OptionsBox.tabControl1.TabPages[5];
            OptionsBox.ShowDialog();
        }

        private void Menu_AboutThisExample_Click(object sender, EventArgs e)
        {
            AboutBox = new AboutBoxType();
            AboutBox.ShowDialog();
        }

        private void Menu_MakeNewImage_Click(object sender, EventArgs e)
        {
            DicomImage Image = new DicomImage();
            int s = 513;
            int r = 256;
            byte[,] Pixel = new byte[s, s];
            int i, j;

            Image.Name = "Test Image";
            Image.InstanceUID = DicomGlobal.NewUID();
            Image.PatientID = "Test Image 001";
            Image.AccessionNumber = "1";

            Image.DataSet.Add(0x0008, 0x0016, DicomObjects.DicomUIDs.SOPClasses.SecondaryCapture);
            Image.DataSet.Add(0x0028, 0x0002, 1);			  //  samples/pixel
            Image.DataSet.Add(0x0028, 0x0004, "MONOCHROME2"); // photometric interpreation
            Image.DataSet.Add(0x0028, 0x0010, s);			  // X
            Image.DataSet.Add(0x0028, 0x0011, s);			  // Y
            Image.DataSet.Add(0x0028, 0x0100, 8);			  // bits allocated;
            Image.DataSet.Add(0x0028, 0x0101, 8);			  // bits stored;
            Image.DataSet.Add(0x0028, 0x0102, 7);			  // high bit;

            for (i = 1; i < s; i++)
            {
                for (j = 1; j < s; j++)
                {
                    Pixel[i, j] = Convert.ToByte(((i + j) / 2) / 256);
                }
            }

            for (i = -r; i <= r; i++)
            {
                for (j = -r; j <= r; j++)
                {
                    if ((i * i + j * j) < (r * r))
                    {
                        Pixel[i + s / 2, j + s / 2] = Convert.ToByte(Math.Sqrt((i * i + j * j) / ((double)(r * r))) * 255);
                    }
                }
            }

            Image.DataSet.Add(0x7FE0, 0x0010, Pixel);
            Viewer.Images.Add(Image);
        }

        private void CImageIndex_MouseUp(object sender, MouseEventArgs e)
        {
            if (Viewer.Images.Count > 0)
            {
                Viewer.CurrentIndex = (int)CImageIndex.Value;
                PatientName.Text = Viewer.Images[Viewer.CurrentIndex].Name + "";
            }
        }

        private void Rows_MouseUp(object sender, MouseEventArgs e)
        {
            Viewer.MultiRows = (short)Rows.Value;
        }

        private void Columns_MouseUp(object sender, MouseEventArgs e)
        {
            Viewer.MultiColumns = (short)Columns.Value;
        }

        private DicomLabel MarkerLabel(DicomImage Image)
        {
            RectangleF A = new RectangleF
            {
                Size = new SizeF(200, 200)
            };

            DicomLabel label = new DicomLabel
            {
                LabelType = DicomObjects.Enums.LabelType.Special,
                ScaleMode = DicomObjects.Enums.ScaleMode.Image,
                ScaleFontSize = true,
                Area = A,
                TextBrush = Brushes.Red,
                Margin = 2
            };

            Image.Labels.Add(label);

            return label;
        }

        private void UpdateMarkers()
        {
            DicomLabel l;

            foreach (DicomImage Image in Viewer.Images)
            {
                // remove existing markers
                for (int i = Image.Labels.Count - 1; i > 0; i--)
                {
                    l = Image.Labels[i];
                    if (l.LabelType == DicomObjects.Enums.LabelType.Special)
                    {
                        Image.Labels.Remove(l);
                    }
                }

                if (AnatomicMarkers.Checked)
                {
                    l = MarkerLabel(Image);
                    l.Left = 0;
                    l.Top = Image.Size.Height / 2;
                    l.Text = "LEFT";

                    l = MarkerLabel(Image);
                    l.Left = Image.Size.Width / 2;
                    l.Top = 0;
                    l.Text = "TOP";

                    l = MarkerLabel(Image);
                    l.Left = Image.Size.Width - 30;
                    l.Top = Image.Size.Height / 2;
                    l.Text = "RIGHT";

                    l = MarkerLabel(Image);
                    l.Left = Image.Size.Width / 2;
                    l.Top = Image.Size.Height - 50;
                    l.Text = "BOTTOM";

                    Image.Update();
                }
            }
        }

        private void AnatomicMarkers_CheckedChanged(object sender, EventArgs e)
        {
            UpdateMarkers();
            Viewer.Refresh();
        }

        private void PixelValue_CheckedChanged(object sender, EventArgs e)
        {
            GetSelectedImage().MinificationMode = DicomObjects.Enums.FilterMode.Replicate;
        }

        private void MovingAverage_CheckedChanged(object sender, EventArgs e)
        {
            GetSelectedImage().MinificationMode = DicomObjects.Enums.FilterMode.MovingAverage;
        }

        private void Replicate_CheckedChanged(object sender, EventArgs e)
        {
            GetSelectedImage().MagnificationMode = DicomObjects.Enums.FilterMode.Replicate;
        }

        private void BSpine_CheckedChanged(object sender, EventArgs e)
        {
            GetSelectedImage().MagnificationMode = DicomObjects.Enums.FilterMode.BSpline;
        }

        private void CubicSpine_CheckedChanged(object sender, EventArgs e)
        {
            GetSelectedImage().MagnificationMode = DicomObjects.Enums.FilterMode.CubicSpline;
        }


        private void Form1_Load(object sender, EventArgs e)
        {
            OptionsBox = new OptionsBoxType();
            RetrieveBox = new RetrieveDialogType();
            Menu_AboutThisExample_Click(null, null);
            server = new DicomServer();
            server.InstanceReceived += Server_InstanceReceived;
            server.VerifyReceived += Server_VerifyReceived;
        }

        private void StretchToFit_CheckedChanged(object sender, EventArgs e)
        {
            if (StretchToFit.Checked)
            {
                GetSelectedImage().StretchMode = DicomObjects.Enums.StretchModes.StretchCentred;
                ZoomSlider.Visible = false;
                ZoomLabel.Visible = false;
                Zoom1.Visible = false;
            }
            else
            {
                GetSelectedImage().StretchMode = DicomObjects.Enums.StretchModes.NoStretch;
                ZoomSlider.Visible = true;
                ZoomLabel.Visible = true;
                Zoom1.Visible = true;
            }
        }

        private void EndMagnifier()
        {
            if (Zooming)
            {
                //Zooming = false;
                Viewer.Images.Remove(Viewer.Images[Viewer.Images.Count - 1]);
                ZoomImage = null;
                ZoomIndex = -1;
            }
        }

        private void SetNewMagnifier(Point p)
        {
            if (!Zooming)
                return;

            int Index = Viewer.ImageIndex(p);
            if (Index >= 0 && Index < Viewer.Images.Count)
            {
                ZoomIndex = Index;
                ZoomImage = Viewer.Images[Index].Clone(true) as DicomImage;
                ZoomImage.StretchMode = DicomObjects.Enums.StretchModes.NoStretch;
                Viewer.Images.Add(ZoomImage);
                ZoomImage.Zoom = DicomGlobal.Zoom(Viewer.Images[Index].Matrix(Viewer)) * 2;
            }
        }

        private void SetMagnifier(Point p)
        {
            if (!Zooming)
                return;

            int IMIndex = Viewer.ImageIndex(p);
            float sizef = 0.1F;
            System.Drawing.Drawing2D.Matrix mx;
            System.Drawing.Drawing2D.Matrix mZoom;

            if (IMIndex == Viewer.Images.Count - 1)
            {
                IMIndex = Viewer.ImageIndices(p)[1];
            }

            //check if you//ve moved onto a new Image
            if (IMIndex != ZoomIndex)
            {
                EndMagnifier();
                SetNewMagnifier(p);
            }

            if (IMIndex >= 0)
            {
                RectangleF Rect = new RectangleF((p.X / (float)Viewer.ClientSize.Width) - (sizef / 2), (p.Y / (float)Viewer.ClientSize.Height) - (sizef / 2), sizef, sizef);
                ZoomImage.Area = Rect;

                mx = Viewer.Matrix(IMIndex);
                mx.Invert();
                Point[] pts = new Point[1];
                pts[0] = p;
                mx.TransformPoints(pts);

                mZoom = Viewer.Matrix(Viewer.Images.IndexOf(ZoomImage));
                mZoom.TransformPoints(pts);

                ZoomImage.Scroll = new Point(Convert.ToInt32(p.X - pts[0].X + ZoomImage.Scroll.X), Convert.ToInt32(p.Y - pts[0].Y + ZoomImage.Scroll.Y));
            }
        }

        double CalculateCobb(double[] CobbXYCoord)
        {
            double t1;
            double t2;
            double angle;
            t1 = (CobbXYCoord[5] - CobbXYCoord[7]) / (CobbXYCoord[4] - CobbXYCoord[6]);
            t2 = (CobbXYCoord[1] - CobbXYCoord[3]) / (CobbXYCoord[0] - CobbXYCoord[2]);
            angle = Math.Atan((t1 - t2) / (1 + t1 * t2));
            if (double.IsNaN(angle))
            {
                angle = 90.00;
            }
            else
            {
                angle = Math.Abs((180 / Math.PI) * (angle));
                angle = Math.Round(angle, 2);
            }
            return angle;
        }


        private void Menu_CineModeForward_Click(object sender, EventArgs e)
        {
            GetSelectedImage().CineMode = DicomObjects.Enums.CineMode.Forward;
        }

        private void Menu_CineModeRepeat_Click(object sender, EventArgs e)
        {
            GetSelectedImage().CineMode = DicomObjects.Enums.CineMode.Repeat;
        }

        private void Menu_CineModeOscillate_Click(object sender, EventArgs e)
        {
            GetSelectedImage().CineMode = DicomObjects.Enums.CineMode.Oscillate;
        }

        private void Menu_CineModeRepeatReverse_Click(object sender, EventArgs e)
        {
            GetSelectedImage().CineMode = DicomObjects.Enums.CineMode.RepeatReverse;
        }

        private void Menu_CineModeReverse_Click(object sender, EventArgs e)
        {
            GetSelectedImage().CineMode = DicomObjects.Enums.CineMode.Reverse;
        }

        private void Menu_CineModeStatic_Click(object sender, EventArgs e)
        {
            GetSelectedImage().CineMode = DicomObjects.Enums.CineMode.Static;
        }

        private void Server_InstanceReceived(object sender, InstanceReceivedArgs e)
        {
            Viewer.Images.Add(new DicomImage(e.Instance));
            e.Status = 0;
        }

        private void Server_VerifyReceived(object sender, VerifyReceivedArgs e)
        {
            e.Status = 0;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            server.UnlistenAll();
        }

        private void Viewer_DataChanged(object sender)
        {
            bool PreState;
            Rows.Value = Viewer.MultiRows;
            Columns.Value = Viewer.MultiColumns;
            CImageIndex.Maximum = Viewer.Images.Count - 1;

            if (Viewer.Images.Count > 0)
            {
                CImageIndex.Value = Viewer.CurrentIndex;
                PatientName.Text = GetSelectedImage().Name + "";
                PreState = !(GetSelectedImage().PresentationState == null);
                Zoom1.Visible = (!PreState) && (GetSelectedImage().StretchMode == DicomObjects.Enums.StretchModes.NoStretch);
                ZoomSlider.Visible = Zoom1.Visible;
                ZoomLabel.Visible = ZoomSlider.Visible;
                StretchToFit.Visible = !PreState;
                StretchToFit.Checked = GetSelectedImage().StretchMode != DicomObjects.Enums.StretchModes.NoStretch;

                DicomImage im;
                im = GetSelectedImage();

                if (PreState || im.DataSet[0x0028, 0x3010].Exists)
                {
                    WidthSlider.Visible = false;
                    LevelSlider.Visible = false;
                    WidthLabel.Visible = false;
                    LevelLabel.Visible = false;
                    Width1.Visible = false;
                    Level1.Visible = false;

                }
                else
                {
                    WidthSlider.Visible = true;
                    LevelSlider.Visible = true;
                    WidthLabel.Visible = true;
                    LevelLabel.Visible = true;
                    Width1.Visible = true;
                    Level1.Visible = true;

                    const float cen = 0;
                    im.GetMinAndMax(out float min, out float max, cen, true);

                    WidthSlider.Maximum = (int)((max - min) * 1.5);
                    WidthSlider.Minimum = (int)min;
                    WidthSlider.Value = (int)GetSelectedImage().Width;
                    Width1.Text = WidthSlider.Value.ToString();
                    LevelSlider.Maximum = (int)max;
                    LevelSlider.Minimum = (int)min;
                    LevelSlider.Value = (int)GetSelectedImage().Level;
                    Level1.Text = LevelSlider.Value.ToString();
                }
            }
            else
            {
                WidthSlider.Visible = false;
                WidthLabel.Visible = false;
                Width1.Visible = false;
                LevelSlider.Visible = false;
                LevelLabel.Visible = false;
                Level1.Visible = false;
                ZoomSlider.Visible = false;
                Zoom1.Visible = false;
                ZoomLabel.Visible = false;
                StretchToFit.Visible = false;
                PatientName.Text = "";
            }
            NewData();
            UpdateMarkers();
        }

        private void Viewer_MouseUp(object sender, MouseEventArgs e)
        {
            WindowedImage = null;
            ScrolledImage = null;
            Displayvalues.Text = "";

            if (MouseFunction == MouseFunctionEnums.Windowing)
            {
                Viewer.CurrentImage.MinificationMode = miniMode;
                Viewer.CurrentImage.MagnificationMode = magiMode;
            }

            if (MouseFunction == MouseFunctionEnums.MagnifyingGlass && Zooming)
            {
                EndMagnifier();
                Zooming = false;
            }

            if (MouseFunction == MouseFunctionEnums.CropImage)
            {
                LabelDrawing = false;
                Point offset = new Point((int)CurrentLabel.Left, (int)CurrentLabel.Top);
                Size pSize = new Size((int)CurrentLabel.Width, (int)CurrentLabel.Height);
                DicomImage CroppedImage = SelectedImage.SubImage(offset, pSize, 1.0F, 1);
                Viewer.Images.Add(CroppedImage);
                Viewer.Labels.Clear();
            }

            if (MouseFunction == MouseFunctionEnums.EditAnnotation && LabelSelected)
            {
                // Important for labelmove, re-initialises label positions after a label move event
                InitialTop = CurrentLabel.Area.Y;
                InitialLeft = CurrentLabel.Area.X;
                InitialHeight = CurrentLabel.Area.Size.Height;
                InitialWidth = CurrentLabel.Area.Size.Width;
                LabelPoints = (CurrentLabel.Points);
            }

            if (MouseFunction == MouseFunctionEnums.AddAnnotation || MouseFunction == MouseFunctionEnums.Measure)
            {
                LabelDrawing = false;

                if (LabelForm.Control.Checked) // Attach CurrentLabel to Viewer
                {
                    Viewer.Labels.Add(CurrentLabel);
                }
                else // Attach CurrentLabel to Target Image
                {
                    Point p = new Point((int)CurrentLabel.Left, (int)CurrentLabel.Top);
                    DicomImage im = Viewer.Images[Viewer.ImageIndex(p)];
                    Viewer.Labels.Remove(CurrentLabel);
                    CurrentLabel.Rescale(Viewer, Viewer.ImageIndex(p), LabelForm.ScaleMode);

                    im.Labels.Add(CurrentLabel);

                    if (MouseFunction == MouseFunctionEnums.Measure)
                    {
                        if (CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Line || CurrentLabel.LabelType == DicomObjects.Enums.LabelType.PolyLine)
                        {
                            Point labeltop = new Point(Convert.ToInt32(CurrentLabel.Left), Convert.ToInt32(CurrentLabel.Top));
                            InfoLabel.Text = CurrentLabel.ROILength(Viewer, Viewer.ImageIndex(labeltop)).ToString("####.#") + " " + CurrentLabel.ROIDistanceUnits(Viewer, Viewer.ImageIndex(labeltop));
                            InfoLabel.AddPoint(InfoLabel.Top, InfoLabel.Left);
                            InfoLabel.ScaleMode = DicomObjects.Enums.ScaleMode.Image;
                        }
                        else
                        {
                            if (CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Polygon || CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Rectangle || CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Ellipse)
                            {
                                MessageBox.Show(CurrentLabel.ROIArea(Viewer, Viewer.CurrentIndex) + " square " + CurrentLabel.ROIDistanceUnits(im));
                                MessageBox.Show("Mean value = " + CurrentLabel.ROIMean(im, true).ToString());
                            }
                        }
                    }
                }

                if (CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Text)
                {
                    CurrentLabel.Font = LabelForm.fontDialog1.Font;
                    CurrentLabel.Text = Microsoft.VisualBasic.Interaction.InputBox("Enter Label Text", "DicomObjects.NET Label Example", "", 500, 500);
                }
                CurrentLabel = null;
            }
        }


        private void Viewer_MouseDown(object sender, MouseEventArgs e)
        {
            Point p = new Point(e.X, e.Y);
            int Index = Viewer.ImageIndex(p);

            bool leftoflabel;
            bool abovelabel;
            int labelcentreX, labelcentreY;
            bool ViewerLabels;
            bool ImageLabels;

            switch (MouseFunction)
            {
                case MouseFunctionEnums.SelectImage:
                    if (Index < 0) // nothing selected
                    {
                        if (isSelectedImage)
                        {
                            isSelectedImage = false;
                            SelectedImage.BorderPen.Width = 0;
                            SelectedImage = null;
                        }
                    }
                    if (Index >= 0 && Index < Viewer.Images.Count)
                    {
                        if (isSelectedImage)
                        {
                            SelectedImage.BorderPen.Width = 0;
                        }
                        SelectedImage = Viewer.Images[Index];
                        isSelectedImage = true;
                        SelectedImage.BorderPen.Width = 1;
                        SelectedImage.BorderPen.Color = System.Drawing.Color.Red;
                    }
                    Viewer.Refresh();
                    break;

                case MouseFunctionEnums.Windowing:
                    if (Viewer.Images.Count > 0)
                    {
                        if (Index >= 0 && Index < Viewer.Images.Count)
                        {
                            WindowedImage = Viewer.Images[Index];
                            BaseX = GetSelectedImage().Width - e.X;
                            BaseY = GetSelectedImage().Level - e.Y;

                            miniMode = Viewer.CurrentImage.MinificationMode;
                            magiMode = Viewer.CurrentImage.MagnificationMode;

                            Viewer.CurrentImage.MinificationMode = DicomObjects.Enums.FilterMode.Replicate;
                            Viewer.CurrentImage.MagnificationMode = DicomObjects.Enums.FilterMode.Replicate;
                        }
                    }
                    break;

                case MouseFunctionEnums.Scroll:
                    if (Index >= 0 && Index < Viewer.Images.Count)
                    {
                        ScrolledImage = Viewer.Images[Index];
                        BaseX = e.X - ScrolledImage.Scroll.X;
                        BaseY = e.Y - ScrolledImage.Scroll.Y;
                    }
                    break;

                case MouseFunctionEnums.AddAnnotation:
                case MouseFunctionEnums.Measure:
                    if (LabelSelected)
                    {
                        CurrentLabel.SelectMode = DicomObjects.Enums.SelectMode.None;
                        LabelSelected = false;
                    }
                    CurrentLabel = new DicomLabel
                    {
                        LabelType = LabelForm.labelType,
                        TextBrush = new SolidBrush(LabelForm.ForeColour.BackColor),
                        Font = LabelForm.fontDialog1.Font,

                        Pen = new Pen(LabelForm.ForeColour.BackColor, Convert.ToInt16(LabelForm.LineWidth.Text)),
                        ShowTextBox = false
                    };

                    if (!LabelForm.Transparent.Checked)
                        CurrentLabel.Brush = new SolidBrush(LabelForm.BackColour.BackColor);
                    LabelDrawing = true;

                    CurrentLabel.Left = e.X;
                    CurrentLabel.Top = e.Y;

                    CurrentLabel.AddPoint(e.X, e.Y);
                    InfoLabel = new DicomLabel();
                    Viewer.Labels.Add(CurrentLabel);
                    Viewer.Labels.Add(InfoLabel);
                    break;

                case MouseFunctionEnums.EditAnnotation:
                    // Select Label
                    if (e.Button == MouseButtons.Left)
                    {
                        ViewerLabels = true;
                        ImageLabels = true;

                        DicomLabelCollection labelList;
                        SelectedImage = Viewer.Images[Index];
                        labelList = Viewer.LabelHits(new Point(e.X, e.Y), ViewerLabels, ImageLabels);

                        if (LabelSelected)
                        {
                            CurrentLabel.SelectMode = DicomObjects.Enums.SelectMode.None;
                            CurrentLabel = new DicomLabel();
                            LabelSelected = false;
                        }

                        if (labelList.Count > 0)
                        {
                            //The line below can be modified to refer to any label within the collection
                            //This example selects the first label within the collection
                            CurrentLabel = labelList[0];
                            CurrentLabel.SelectPen = Pens.Green;
                            if (CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Polygon || CurrentLabel.LabelType == DicomObjects.Enums.LabelType.PolyLine)
                                CurrentLabel.SelectMode = DicomObjects.Enums.SelectMode.AllHandles;
                            else
                                CurrentLabel.SelectMode = DicomObjects.Enums.SelectMode.AllHandles | DicomObjects.Enums.SelectMode.Box | DicomObjects.Enums.SelectMode.BoxHandles;
                            LabelSelected = true;
                            LabelPoints = CurrentLabel.Points;
                        }
                    }

                    // Right Button to Move Label
                    if (e.Button == MouseButtons.Right)
                    {
                        InitialX = e.X;
                        InitialY = e.Y;

                        // record the initial position
                        InitialHeight = CurrentLabel.Area.Size.Height;
                        InitialWidth = CurrentLabel.Area.Size.Width;
                        InitialLeft = CurrentLabel.Area.X;
                        InitialTop = CurrentLabel.Area.Y;

                        // defining the centre of a label not tied to the image
                        labelcentreX = (int)(CurrentLabel.Area.X + CurrentLabel.Area.Size.Width / 2);
                        labelcentreY = (int)(CurrentLabel.Area.Y + CurrentLabel.Area.Size.Height / 2);

                        leftoflabel = false;
                        abovelabel = false;

                        if (e.X < labelcentreX)
                            leftoflabel = true;

                        if (e.Y > labelcentreY)
                            abovelabel = true;

                        if (CurrentLabel.Width < 0)
                            leftoflabel = !leftoflabel;

                        if (CurrentLabel.Height < 0)
                            abovelabel = !abovelabel;

                        if (leftoflabel && !abovelabel)
                            LabelEdge = LabelEdgeType.TopLeft;

                        if (leftoflabel && abovelabel)
                            LabelEdge = LabelEdgeType.BottomLeft;

                        if (!leftoflabel && !abovelabel)
                            LabelEdge = LabelEdgeType.TopRight;

                        if (!leftoflabel && abovelabel)
                            LabelEdge = LabelEdgeType.BottomRight;
                    }

                    // Middle Button to Resize the Label
                    if (e.Button == MouseButtons.Middle)
                    {
                        InitialX = e.X;
                        InitialY = e.Y;
                        LabelPoints = CurrentLabel.Points;
                    }

                    break;

                case MouseFunctionEnums.MagnifyingGlass:
                    if (Index >= 0 && Index < Viewer.Images.Count)
                    {
                        Zooming = true;
                        Point p2 = new Point(e.X, e.Y);
                        SetNewMagnifier(p2);
                        SetMagnifier(p2);
                    }
                    break;

                case MouseFunctionEnums.CropImage:
                    SelectedImage = Viewer.Images[Index];
                    LabelDrawing = true;
                    CurrentLabel = new DicomLabel
                    {
                        LabelType = DicomObjects.Enums.LabelType.Rectangle,
                        Pen = new Pen(Color.Red, Convert.ToInt32(LabelForm.LineWidth.Text)),
                        Left = e.X,
                        Top = e.Y
                    };
                    CurrentLabel.AddPoint(e.X, e.Y);
                    Viewer.Labels.Add(CurrentLabel);
                    break;

                case MouseFunctionEnums.CobbMeasurement:
                    switch (ClickNum)
                    {
                        case 1:
                            {
                                CobbCoord[0] = e.X;
                                CobbCoord[1] = e.Y;
                                ClickNum = 2;
                                break;
                            }

                        case 2:
                            {
                                CobbCoord[2] = e.X;
                                CobbCoord[3] = e.Y;
                                ClickNum = 3;
                                // draw line1
                                CurrentLabel = new DicomLabel
                                {
                                    LabelType = DicomObjects.Enums.LabelType.Line,
                                    Top = (short)CobbCoord[1],
                                    Left = (short)CobbCoord[0],
                                    Height = (short)(CobbCoord[3] - CobbCoord[1]),
                                    Width = (short)(CobbCoord[2] - CobbCoord[0]),
                                    Pen = new Pen(Color.Red, 1)
                                };
                                Viewer.Labels.Add(CurrentLabel);
                                Viewer.Refresh();
                                break;
                            }

                        case 3:
                            {
                                CobbCoord[4] = e.X;
                                CobbCoord[5] = e.Y;
                                ClickNum = 4;
                                break;
                            }

                        case 4:
                            {
                                CobbCoord[6] = e.X;
                                CobbCoord[7] = e.Y;
                                ClickNum = 1;
                                // draw line2
                                CurrentLabel = new DicomLabel
                                {
                                    LabelType = DicomObjects.Enums.LabelType.Line,
                                    Top = (short)CobbCoord[5],
                                    Left = (short)CobbCoord[4],
                                    Height = (short)(CobbCoord[7] - CobbCoord[5]),
                                    Width = (short)(CobbCoord[6] - CobbCoord[4]),
                                    Pen = new Pen(Color.Red, 1)
                                };
                                Viewer.Labels.Add(CurrentLabel);
                                Viewer.Refresh();
                                // calculate the angle between line1 and line2
                                double ang1;

                                ang1 = CalculateCobb(CobbCoord);
                                MessageBox.Show("The angle is " + ang1.ToString() + "");
                                break;
                            }
                    }
                    break;

                case MouseFunctionEnums.Protractor:
                    switch (ClickNum)
                    {
                        case 1:
                            XYCoord[0] = e.X;
                            XYCoord[1] = e.Y;
                            ClickNum = 2;
                            break;

                        //second point
                        case 2:
                            XYCoord[2] = e.X;
                            XYCoord[3] = e.Y;
                            //draws a line between the first and second point
                            CurrentLabel = new DicomLabel
                            {
                                LabelType = DicomObjects.Enums.LabelType.Line,
                                Top = (short)XYCoord[1],
                                Left = (short)XYCoord[0],
                                Height = (short)(XYCoord[3] - XYCoord[1]),
                                Width = (short)(XYCoord[2] - XYCoord[0]),
                                Pen = Pens.Red
                            };
                            Viewer.Labels.Add(CurrentLabel);
                            Viewer.Refresh();
                            ClickNum = 3;
                            break;

                        //third point
                        case 3:

                            XYCoord[4] = e.X;
                            XYCoord[5] = e.Y;
                            //draws a line between the second and third point
                            CurrentLabel = new DicomLabel
                            {
                                LabelType = DicomObjects.Enums.LabelType.Line,
                                Top = (short)XYCoord[5],
                                Left = (short)XYCoord[4],
                                Height = (short)(XYCoord[3] - XYCoord[5]),
                                Width = (short)(XYCoord[2] - XYCoord[4]),
                                Pen = Pens.Red
                            };
                            Viewer.Labels.Add(CurrentLabel);
                            Viewer.Refresh();
                            double diffx1, diffy1, diffx3, diffy3;
                            //creates two vector cooridnates
                            diffx1 = XYCoord[0] - XYCoord[2];
                            diffy1 = XYCoord[1] - XYCoord[3];
                            diffx3 = XYCoord[4] - XYCoord[2];
                            diffy3 = XYCoord[5] - XYCoord[3];

                            //calculates the angle between the two vectors
                            double crossproduct, cosang;
                            crossproduct = (diffx1 * diffx3) + (diffy1 * diffy3);
                            cosang = crossproduct / (Math.Sqrt((diffx1 * diffx1) + (diffy1 * diffy1)) * Math.Sqrt((diffx3 * diffx3) + (diffy3 * diffy3)));

                            double ang;
                            //calculates the inverse cosine and converts the ang from radians into degrees
                            ang = (180 / Math.PI) * (Math.Atan(-cosang / Math.Sqrt(1 - cosang * cosang)) + 2 * Math.Atan(1));

                            //displayes the angle between the 2 vectors as a label that is positioned between the vectors.
                            CurrentLabel = new DicomLabel
                            {
                                LabelType = DicomObjects.Enums.LabelType.Text,
                                TextBrush = Brushes.Yellow,
                                Top = (short)((XYCoord[1] + XYCoord[5]) / 2),
                                Left = (short)(((XYCoord[0] + XYCoord[4]) / 2) - 53),
                                Height = 20,
                                Width = 100,
                                Text = String.Format("{0:F2}", ang) + "  Deg"
                            };

                            Viewer.Labels.Add(CurrentLabel);
                            Viewer.Refresh();
                            ClickNum = 1;
                            break;
                    }
                    break;
            } // End switch
        }

        private void Viewer_MouseMove(object sender, MouseEventArgs e)
        {
            Point p = new Point(e.X, e.Y);
            int Index = Viewer.ImageIndex(p);

            if (Index < 0) return;

            float OffsetX, OffsetY;

            if (e.Button > 0)
            {
                switch (MouseFunction)
                {
                    case MouseFunctionEnums.Windowing:
                        if (WindowedImage != null)
                        {
                            WindowedImage.Width = BaseX + e.X * 3;
                            WindowedImage.Level = BaseY + e.Y * 3;
                        }
                        break;

                    case MouseFunctionEnums.Scroll:
                        Point sp = new Point(e.X - (int)BaseX, e.Y - (int)BaseY);
                        ScrolledImage.Scroll = sp;
                        break;

                    case MouseFunctionEnums.AddAnnotation:
                    case MouseFunctionEnums.Measure:
                    case MouseFunctionEnums.CropImage:
                        if (LabelDrawing)
                        {
                            RectangleF A;
                            SizeF S = new SizeF();
                            A = CurrentLabel.Area;
                            S.Width = e.X - A.Left;
                            S.Height = e.Y - A.Top;
                            A.Size = S;
                            CurrentLabel.Area = A;

                            CurrentLabel.AddPoint(e.X, e.Y);

                            if (MouseFunction == MouseFunctionEnums.Measure)
                            {
                                Point labeltop = new Point(Convert.ToInt32(CurrentLabel.Left), Convert.ToInt32(CurrentLabel.Top));

                                if (CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Line || CurrentLabel.LabelType == DicomObjects.Enums.LabelType.PolyLine)
                                    InfoLabel.Text = CurrentLabel.ROILength(Viewer, Viewer.ImageIndex(labeltop)).ToString("####.#") + " " + CurrentLabel.ROIDistanceUnits(Viewer, Viewer.ImageIndex(labeltop));
                                else
                                    InfoLabel.Text = "";

                                InfoLabel.TextBrush = new SolidBrush(LabelForm.ForeColour.BackColor);
                                InfoLabel.Font = LabelForm.fontDialog1.Font;

                                InfoLabel.Pen = new Pen(LabelForm.ForeColour.ForeColor, Convert.ToInt16(LabelForm.LineWidth.Text));
                                InfoLabel.ShowTextBox = false;

                                if (!LabelForm.Transparent.Checked)
                                    InfoLabel.Brush = new SolidBrush(LabelForm.BackColour.BackColor);

                                InfoLabel.Width = 100;
                                InfoLabel.Height = 100;
                                InfoLabel.Top = e.Y - 10;
                                InfoLabel.Left = e.X;

                                InfoLabel.AddPoint(e.X, e.Y);
                            }
                        }
                        break;
                    case MouseFunctionEnums.EditAnnotation:
                        if (!LabelSelected)
                            return;

                        OffsetX = e.X - InitialX;
                        OffsetY = e.Y - InitialY;
                        if (e.Button == MouseButtons.Right)
                        {
                            // To move polyline and polygone within the viewer all points forming the label have to be read into a variant
                            //if label is a polyline(4) or Polygone(5) then each of the points forming the label need to be moved. 
                            if (CurrentLabel.LabelType == DicomObjects.Enums.LabelType.PolyLine || CurrentLabel.LabelType == DicomObjects.Enums.LabelType.Polygon)
                            {
                                for (int i = 0; i < CurrentLabel.Points.Length; i++)
                                {
                                    CurrentLabel.Points[i].X = CurrentLabel.Points[i].X + OffsetX;
                                    CurrentLabel.Points[i].Y = CurrentLabel.Points[i].Y + OffsetY;
                                }
                            }
                            else // other label types, text, rectangle, etc.
                            {
                                CurrentLabel.Left += OffsetX;
                                CurrentLabel.Top += OffsetY;
                            }

                            InitialX = e.X;
                            InitialY = e.Y;
                            Viewer.Refresh();
                        }

                        if (e.Button == MouseButtons.Middle)
                        {
                            switch (LabelEdge)
                            {
                                case LabelEdgeType.BottomRight:
                                    RectangleF A;
                                    SizeF S = new SizeF();
                                    A = CurrentLabel.Area;
                                    S.Width = InitialWidth + OffsetX;
                                    S.Height = InitialHeight + OffsetY;
                                    A.Size = S;
                                    CurrentLabel.Area = A;
                                    break;

                                case LabelEdgeType.BottomLeft:
                                    RectangleF A1;
                                    SizeF S1 = new SizeF();
                                    A1 = CurrentLabel.Area;
                                    A1.X = InitialLeft + OffsetX;
                                    S1.Width = InitialWidth - OffsetX;
                                    S1.Height = InitialHeight + OffsetY;
                                    A1.Size = S1;
                                    CurrentLabel.Area = A1;
                                    break;

                                case LabelEdgeType.TopRight:
                                    RectangleF A2;
                                    SizeF S2 = new SizeF();
                                    A2 = CurrentLabel.Area;
                                    A2.Y = InitialTop + OffsetY;
                                    S2.Width = InitialWidth + OffsetX;
                                    S2.Height = InitialHeight - OffsetY;
                                    A2.Size = S2;
                                    CurrentLabel.Area = A2;
                                    break;

                                case LabelEdgeType.TopLeft:
                                    RectangleF A3;
                                    SizeF S3 = new SizeF();
                                    A3 = CurrentLabel.Area;
                                    A3.Y = InitialTop + OffsetY;
                                    A3.X = InitialLeft + OffsetX;
                                    S3.Width = InitialWidth - OffsetX;
                                    S3.Height = InitialHeight - OffsetY;
                                    A3.Size = S3;
                                    CurrentLabel.Area = A3;
                                    break;
                            }
                        }
                        break;
                    case MouseFunctionEnums.MagnifyingGlass:
                        Point p3 = new Point(e.X, e.Y);
                        SetMagnifier(p3);
                        break;

                    case MouseFunctionEnums.PixelValues:
                        DicomLabel l = new DicomLabel
                        {
                            LabelType = DicomObjects.Enums.LabelType.Rectangle,
                            Left = e.X,
                            Top = e.Y,
                            Width = 1,
                            Height = 1
                        };

                        l.Rescale(Viewer, Index, DicomObjects.Enums.ScaleMode.Image);
                        Displayvalues.Text = "[X : " + e.X.ToString() + ",  Y : " + e.Y.ToString() + "] -- Pixel Value : " + l.ROIMean(Viewer.Images[Index], true).ToString();
                        Displayvalues.Refresh();
                        break;
                } // end switch
            }
        }

        private void LevelSlider_MouseDown(object sender, MouseEventArgs e)
        {
            miniMode = GetSelectedImage().MinificationMode;
            magiMode = GetSelectedImage().MagnificationMode;

            GetSelectedImage().MinificationMode = DicomObjects.Enums.FilterMode.Replicate;
            GetSelectedImage().MagnificationMode = DicomObjects.Enums.FilterMode.Replicate;
        }

        private void LevelSlider_MouseUp(object sender, MouseEventArgs e)
        {
            GetSelectedImage().MinificationMode = miniMode;
            GetSelectedImage().MagnificationMode = magiMode;
        }

        private void WidthSlider_MouseDown(object sender, MouseEventArgs e)
        {
            miniMode = GetSelectedImage().MinificationMode;
            magiMode = GetSelectedImage().MagnificationMode;

            GetSelectedImage().MinificationMode = DicomObjects.Enums.FilterMode.Replicate;
            GetSelectedImage().MagnificationMode = DicomObjects.Enums.FilterMode.Replicate;
        }

        private void WidthSlider_MouseUp(object sender, MouseEventArgs e)
        {
            GetSelectedImage().MinificationMode = miniMode;
            GetSelectedImage().MagnificationMode = magiMode;
        }
    }
}
